%feature("docstring") OT::Histogram
"Histogram distribution.

Available constructors:
    Histogram(*first=0., coll=ot.HistogramPairCollection(1)*)

Parameters
----------
first : float
    Lower bound.
coll : :class:`~openturns.HistogramPairCollection`
    Collection of :math:`(l_i, h_i)` where :math:`h_i` is the frequency of the
    class :math:`i` and :math:`l_i` its width.

Notes
-----
Its probability density function is defined as:

.. math::

    f_X(x) = \\\\sum_{i=1}^{n}H_i\\\\;\\\\boldsymbol{1}_{[x_i,x_{i+1}]}(x)

where :math:`H_i=h_i/S` is the relative frequency,
with :math:`S=\\\\sum_{i=1}^n h_i\\\\,l_i` the total frequency of data.
:math:`l_i = x_{i+1} - x_i , 1\\\\leq i \\\\leq n` and :math:`n` is the size of the
`ot.HistogramPairCollection`.

Its first moments are:

.. math::
    :nowrap:

    \\\\begin{eqnarray*}
        \\\\Expect{X} & = & \\\\frac{1}{2 \\\\sum_{i=1}^n h_i\\\\,l_i}
                         \\\\sum_{i=1}^n h_i\\\\,l_i (x_{i+1} + x_i)\\\\\\\\
        \\\\Var{X} & = & \\\\frac{1}{3 \\\\sum_{i=1}^n h_i\\\\,l_i}
                      \\\\sum_{i=1}^n h_i\\\\,l_i (x_{i+1}^2 + x_i\\\\,x_{i+1} + x_i^2)
    \\\\end{eqnarray*}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> collection = HistogramPairCollection(4)
>>> collection[0] = HistogramPair(1.0, 0.5)
>>> collection[1] = HistogramPair(0.7, 1.5)
>>> collection[2] = HistogramPair(1.2, 3.5)
>>> collection[3] = HistogramPair(0.9, 2.5)
>>> distribution = Histogram(-1.5, collection)

Draw a sample:

>>> sample = distribution.getSample(10)"

// ---------------------------------------------------------------------

%feature("docstring") OT::Histogram::getFirst
"Accessor to the distribution's lower bound.

Returns
-------
first : float
    Lower bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Histogram::getPairCollection
"Accessor to the distribution's collection.

Returns
-------
coll : :class:`~openturns.HistogramPairCollection`
    The collection of :math:`(l_i, h_i)` where :math:`h_i` is the frequency of
    the class `i` and :math:`l_i` its width."

// ---------------------------------------------------------------------

%feature("docstring") OT::Histogram::setFirst
"Accessor to the distribution's lower bound.

Parameters
----------
first : float
    Lower bound."

// ---------------------------------------------------------------------

%feature("docstring") OT::Histogram::setPairCollection
"Accessor to the distribution's collection.

Parameters
----------
coll : :class:`~openturns.HistogramPairCollection`
    The collection of :math:`(l_i, h_i)` where :math:`h_i` is the frequency of
    the class `i` and :math:`l_i` its width."
