%feature("docstring") OT::LHSExperiment
"LHS experiment.

Available constructors:
    LHSExperiment(*size*)

    LHSExperiment(*distribution, size*)

Parameters
----------
distribution : :class:`~openturns.Distribution`
    Distribution :math:`\\\\mu` with an independent copula used to generate the set of input data.
size : positive int
    Number :math:`cardI` of points that will be generated in the experiment.

Notes
-----
The method generate generates a NumericalSample of points :math:`\\\\Xi_i`
which points are generated according to :math:`\\\\mu` with the LHS technique:
some cells are determined, with the same probabilistic content according to distribution,
each line and each column contains exactly one cell,
then points are selected among these selected cells.
When the method generate is recalled, the NumericalSample generated changes:
the point selection within the cells changes but not the cells selection.
To change the cell selection, it is necessary to create a new LHS Experiment.

Examples
--------
Create an *LHSExperiment*:

>>> import openturns as ot
>>> ot.RandomGenerator.SetSeed(0)
>>> experiment = ot.LHSExperiment(ot.Normal(2), 5)
>>> sample = experiment.generate()
>>> print(sample)
    [ marginal 1 marginal 2 ]
0 : [  0.280461   0.0925621 ]
1 : [  1.10798   -0.74677   ]
2 : [ -0.804439  -1.26184   ]
3 : [ -1.69566    2.53286   ]
4 : [  0.520312  -0.604502  ]"

// ---------------------------------------------------------------------

%feature("docstring") OT::LHSExperiment::getShuffle
"Return the cell randomization.

Returns
-------
shuffle : :class:`~openturns.Matrix
    For each point, the indices of the shuffled components"
// ---------------------------------------------------------------------

%feature("docstring") OT::LHSExperiment::ComputeShuffle
"Generate a new cell randomization for external use.

Parameters
----------
dimension : positive int
    Number of input dimension
totalSize : positive int
    Number :math:`cardI` of points that need to be shuffled

Returns
-------
shuffle : :class:`~openturns.Matrix
    For each point, the indices of the shuffled components"
%feature("docstring") OT::LHSExperiment
"LHS experiment.

Available constructors:
    LHSExperiment(*size*)

    LHSExperiment(*distribution, size*)

Parameters
----------
distribution : :class:`~openturns.Distribution`
    Distribution :math:`\\\\mu` with an independent copula used to generate the set of input data.
size : positive int
    Number :math:`cardI` of points that will be generated in the experiment.

Notes
-----
The method generate generates a NumericalSample of points :math:`\\\\Xi_i`
which points are generated according to :math:`\\\\mu` with the LHS technique:
some cells are determined, with the same probabilistic content according to distribution,
each line and each column contains exactly one cell,
then points are selected among these selected cells.
When the method generate is recalled, the NumericalSample generated changes:
the point selection within the cells changes but not the cells selection.
To change the cell selection, it is necessary to create a new LHS Experiment.

Examples
--------
Create an *LHSExperiment*:

>>> import openturns as ot
>>> ot.RandomGenerator.SetSeed(0)
>>> experiment = ot.LHSExperiment(ot.Normal(2), 5)
>>> sample = experiment.generate()
>>> print(sample)
    [ marginal 1 marginal 2 ]
0 : [  0.280461   0.0925621 ]
1 : [  1.10798   -0.74677   ]
2 : [ -0.804439  -1.26184   ]
3 : [ -1.69566    2.53286   ]
4 : [  0.520312  -0.604502  ]"

// ---------------------------------------------------------------------

%feature("docstring") OT::LHSExperiment::getShuffle
"Return the cell randomization.

Returns
-------
shuffle : :class:`~openturns.Matrix
    For each point, the indices of the shuffled cells"
// ---------------------------------------------------------------------

%feature("docstring") OT::LHSExperiment::ComputeShuffle
"Generate a new cell randomization for external use.

Parameters
----------
dimension : positive int
    Number of input dimension
totalSize : positive int
    Number :math:`cardI` of points that need to be shuffled

Returns
-------
shuffle : :class:`~openturns.Matrix
    For each point, the indices of the shuffled cells"
