%feature("docstring") OT::MaximumEntropyOrderStatisticsDistribution
"MaximumEntropyOrderStatistics distribution.

Parameters
----------
coll : sequence of :class:`~openturns.Distribution`
    The marginals, with range verifying :math:`a_i \\\\leq a_{i+1}` and :math:`b_i \\\\leq b_{i+1}`.

Notes
-----
Its realizations are ordered :math:`X_1 \\\\leq \\\\dots \\\\leq X_n`.

Its probability density function is defined as:

.. math::

    f_X(x) = f_1(x_1) \\\\prod\\\\limits_{k=2}^d \\\\phi_k(x_k) \\\\exp\\\\left(-\\\\int_{x_{k-1}}^{x_k} \\\\phi_k(s) ds\\\\right) \\\\mathbf{1}_{x_1 \\\\leq \\\\dots \\\\leq x_d}

             \\\\text{with } \\\\phi_k(x_k) = \\\\frac{f_k(x_k)}{F_{k-1}(x_k)-F_k(x_k)}

Examples
--------
Create a distribution:

>>> import openturns as ot
>>> coll = [ot.Uniform(-1., 1.), ot.LogUniform(1., 1.2), ot.Triangular(3., 4., 5.)]
>>> distribution = ot.MaximumEntropyOrderStatisticsDistribution(coll)

Draw a sample:

>>> sample = distribution.getSample(10)"

// ---------------------------------------------------------------------

%feature("docstring") OT::MaximumEntropyOrderStatisticsDistribution::getDistributionCollection
"Accessor to the distribution's collection.

Returns
-------
coll : sequence
    The marginals."

// ---------------------------------------------------------------------

%feature("docstring") OT::MaximumEntropyOrderStatisticsDistribution::setDistributionCollection
"Accessor to the distribution's collection.

Parameters
----------
coll : sequence
    The marginals."

// ---------------------------------------------------------------------

