%feature("docstring") OT::ResourceMap
"The ResourceMap allows to manage constants that are associated to key strings."

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::Get
"Access a parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.

Returns
-------
value : string
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.Get('DiscreteDistribution-SupportEpsilon')
'1.0e-14'"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::Set
"Access a parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.
value : string
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.Set('DiscreteDistribution-SupportEpsilon', '1.0e-14')"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsBool
"Access a boolean parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.

Returns
-------
value : bool
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsBool('computation-progression-visible')
True"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsBool
"Access a boolean parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.
value : bool
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsBool('computation-progression-visible', True)"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsNumericalScalar
"Access a floating-point parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.
value : float
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsNumericalScalar('SQP-DefaultTau', 0.5)"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsNumericalScalar
"Access a floating-point parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.

Returns
-------
value : float
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsNumericalScalar('SQP-DefaultTau')
0.5"

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::SetAsUnsignedInteger
"Access an integer parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.
value : int
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.SetAsUnsignedInteger('MCMC-DefaultBurnIn', 2000)"


// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetAsUnsignedInteger
"Access an integer parameter.

Parameters
----------
key : string
    An identifier associated to the parameter.

Returns
-------
value : float
    The value associated to that key.

Examples
--------
>>> import openturns as ot
>>> ot.ResourceMap.GetAsUnsignedInteger('MCMC-DefaultBurnIn')
2000..."

// ---------------------------------------------------------------------

%feature("docstring") OT::ResourceMap::GetInstance
"Access the singleton instance.

Returns
-------
instance : :class:`~openturns.ResourceMap`
    The singleton instance."
